@@ -442,7 +442,7 @@ void RichTextComposerTest::testLoadImage()
     QString image2Path = KIconLoader::global()->iconPath(QStringLiteral("arrow-up"), KIconLoader::Small, false);
     QImage image1, image2;
     QVERIFY(image1.load(image1Path));
-    QVERIFY(image2.load(image1Path));
+    QVERIFY(image2.load(image2Path));
 
     edit.setHtml(QStringLiteral("Bla<img src=\"folder-new.png\">Bla"));
 
@@ -464,16 +464,30 @@ void RichTextComposerTest::testLoadImage()
     QCOMPARE(edit.composerControler()->composerImages()->embeddedImages().size(), 1);
 }
 
+void RichTextComposerTest::testWrappedPlainText_data()
+{
+    QTest::addColumn<QString>("input");
+    QTest::addColumn<QString>("output");
+
+    QString defaultStr = QStringLiteral("http://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  https://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\ntest ftp://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\nftps://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  ldap://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test");
+    QTest::newRow("default") << defaultStr << defaultStr;
+    QTest::newRow("empty") << QString() << QString();
+    QTest::newRow("wrap") << QStringLiteral("foosdfsdf sdsf sdfsdfsfs fsf sdfs df sfsdf dsf sdfsdf sf sf sfsdf sdsdf") << QStringLiteral("foosdfsdf sdsf sdfsdfsfs fsf sdfs df sfsdf \ndsf sdfsdf sf sf sfsdf sdsdf");
+    QTest::newRow("wrap-2") << QStringLiteral("test-test-test-test-test-test-test-test-test-test-test-test-test") << QStringLiteral("test-test-test-test-test-test-test-test-test-\ntest-test-test-test");
+    QTest::newRow("wrap-3") << QStringLiteral("test-test-test-test-test-test-test-test-test-test-test-test-test\n\n") << QStringLiteral("test-test-test-test-test-test-test-test-test-\ntest-test-test-test\n\n");
+}
+
 void RichTextComposerTest::testWrappedPlainText()
 {
+    QFETCH(QString, input);
+    QFETCH(QString, output);
     KPIMTextEdit::RichTextComposer edit;
     edit.createActions(new KActionCollection(this));
-    QString text(QStringLiteral("http://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  https://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\ntest ftp://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\nftps://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test\n  ldap://example.org/test-test-test-test-test-test-test-test-test-test-test-test-test"));
-    edit.setPlainText(text);
+    edit.setPlainText(input);
 
     edit.show(); // < otherwise toWrappedPlainText can't work, it needs a layout
 
-    QCOMPARE(edit.composerControler()->toWrappedPlainText(), text);
+    QCOMPARE(edit.composerControler()->toWrappedPlainText(), output);
 }
 
 void RichTextComposerTest::testEnableDisableActions()
