@@ -24,6 +24,7 @@
 #include "nestedlisthelper_p.h"
 #include "inserthtmldialog.h"
 #include <QApplication>
+#include <QRegularExpression>
 
 #include <KColorScheme>
 #include <KMessageBox>
@@ -35,6 +36,7 @@
 #include <QPointer>
 #include <QClipboard>
 #include <QIcon>
+#include <QDebug>
 #include "textutils.h"
 #include "insertimagedialog.h"
 
@@ -55,12 +57,21 @@ public:
     {
         delete nestedListHelper;
     }
+    QColor linkColor()
+    {
+        if (mLinkColor.isValid()) {
+            return mLinkColor;
+        }
+        mLinkColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color();
+        return mLinkColor;
+    }
     void selectLinkText(QTextCursor *cursor) const;
     void fixupTextEditString(QString &text) const;
     void mergeFormatOnWordOrSelection(const QTextCharFormat &format);
     QString addQuotesToText(const QString &inputText);
     void updateLink(const QString &linkUrl, const QString &linkText);
     QFont saveFont;
+    QColor mLinkColor;
     QTextCharFormat painterFormat;
     bool painterActive;
     NestedListHelper *nestedListHelper;
@@ -442,8 +453,8 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::updateLink(con
         // Link formatting does not get applied immediately when setAnchor(true)
         // is called.  So the formatting needs to be applied manually.
         format.setUnderlineStyle(QTextCharFormat::SingleUnderline);
-        format.setUnderlineColor(KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color());
-        format.setForeground(KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color());
+        format.setUnderlineColor(linkColor());
+        format.setForeground(linkColor());
         richtextComposer->activateRichText();
     } else {
         // Remove link details
@@ -583,8 +594,8 @@ void RichTextComposerControler::insertLink(const QString &url)
         // Link formatting does not get applied immediately when setAnchor(true)
         // is called.  So the formatting needs to be applied manually.
         format.setUnderlineStyle(QTextCharFormat::SingleUnderline);
-        format.setUnderlineColor(KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color());
-        format.setForeground(KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color());
+        format.setUnderlineColor(d->linkColor());
+        format.setForeground(d->linkColor());
         // Insert link text specified in dialog, otherwise write out url.
         cursor.insertText(url, format);
 
@@ -620,8 +631,8 @@ void RichTextComposerControler::insertShareLink(const QString &url)
         // Link formatting does not get applied immediately when setAnchor(true)
         // is called.  So the formatting needs to be applied manually.
         format.setUnderlineStyle(QTextCharFormat::SingleUnderline);
-        format.setUnderlineColor(KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color());
-        format.setForeground(KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color());
+        format.setUnderlineColor(d->linkColor());
+        format.setForeground(d->linkColor());
         // Insert link text specified in dialog, otherwise write out url.
         cursor.insertText(url, format);
 
@@ -890,7 +901,7 @@ QString RichTextComposerControler::toWrappedPlainText() const
 QString RichTextComposerControler::toWrappedPlainText(QTextDocument *doc) const
 {
     QString temp;
-    QRegExp rx(QLatin1String("(http|ftp|ldap)s?\\S+-$"));
+    QRegularExpression rx(QLatin1String("(http|ftp|ldap)s?\\S+-$"));
     QTextBlock block = doc->begin();
     while (block.isValid()) {
         QTextLayout *layout = block.layout();
@@ -917,7 +928,6 @@ QString RichTextComposerControler::toWrappedPlainText(QTextDocument *doc) const
     if (temp.endsWith(QLatin1Char('\n'))) {
         temp.chop(1);
     }
-
     d->fixupTextEditString(temp);
     return temp;
 }
