@@ -192,12 +192,12 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
                 d->speller = new Sonnet::Speller();
             }
             if (!d->speller->availableBackends().isEmpty()) {
-                QAction *spellCheckAction = popup->addAction(QIcon::fromTheme(QStringLiteral("tools-check-spelling")), i18n("Check Spelling..."), this, SLOT(slotCheckSpelling()));
+                QAction *spellCheckAction = popup->addAction(QIcon::fromTheme(QStringLiteral("tools-check-spelling")), i18n("Check Spelling..."), this, &RichTextEditor::slotCheckSpelling);
                 if (emptyDocument) {
                     spellCheckAction->setEnabled(false);
                 }
                 popup->addSeparator();
-                QAction *autoSpellCheckAction = popup->addAction(i18n("Auto Spell Check"), this, SLOT(slotToggleAutoSpellCheck()));
+                QAction *autoSpellCheckAction = popup->addAction(i18n("Auto Spell Check"), this, &RichTextEditor::slotToggleAutoSpellCheck);
                 autoSpellCheckAction->setCheckable(true);
                 autoSpellCheckAction->setChecked(checkSpellingEnabled());
                 popup->addAction(autoSpellCheckAction);
@@ -286,6 +286,12 @@ void RichTextEditor::addIgnoreWords(const QStringList &lst)
     addIgnoreWordsToHighLighter();
 }
 
+void RichTextEditor::forceAutoCorrection(bool selectedText)
+{
+    Q_UNUSED(selectedText);
+    //Nothing here
+}
+
 void RichTextEditor::setSearchSupport(bool b)
 {
     if (b) {
